@@ -21,13 +21,7 @@ It is used to test virtual instruments.
 #include "../gui_terminal/instrument_mode_joystick.h"
 
 
-
-
-static void back_to_game_selection(){
-chum_stop_sequencer();
-show_game_selection();
-}
-
+extern ClutterActor *to_main_menu;
 
 //this is same than virtual-instrument
 static gchar notenames[] ={'c','1','d','2','e','f',
@@ -111,26 +105,18 @@ void start_test_instrument(ClutterActor *actor, ClutterEvent *event, gpointer da
     }
   }
 
+  clutter_actor_raise_top(to_main_menu);
+  clutter_actor_show (to_main_menu);
+
   chum_play_sequencer();
-
-ClutterActor *s1 = config_get_configured_actor(NULL,"house");
-clutter_container_add_actor (CLUTTER_CONTAINER (stage), s1);
-clutter_actor_set_position (s1, 720, 5); 
-clutter_actor_set_size (s1, 66, 60);
-clutter_actor_show (s1);
-clutter_actor_set_name(s1, "house");
-clutter_actor_set_reactive(s1, TRUE);
-g_signal_connect (s1, "button-release-event", G_CALLBACK (back_to_game_selection),NULL);
 }
 
 
-
-
 static void slider_motion(ClutterActor *actor, ClutterEvent *event, gpointer data){
 gfloat x_release, y_release;
 clutter_event_get_coords (event, &x_release, &y_release);
 //printf("move: X=%f\n",x_release);
-chum_slider_freq((int)x_release);
+chum_slider_freq((int)x_release+64); //slider can't play frequencies below ~30. 
 }
 
 static void slider_press(ClutterActor *actor, ClutterEvent *event, gpointer data){
@@ -152,7 +138,7 @@ chum_slider_state(FALSE);
 void start_slider(ClutterActor *actor, ClutterEvent *event, gpointer data){
 printf("Slider\n");
   int type=GPOINTER_TO_INT(data);
-  chum_test_instrument(type);
+  chum_test_slider(type);
 
 
  ClutterActor* stage =main_getStage();
@@ -170,17 +156,8 @@ printf("Slider\n");
       g_signal_connect (box, "button-release-event", G_CALLBACK (slider_release),NULL);
       g_signal_connect (box, "motion-event", G_CALLBACK (slider_motion),NULL);
 
+  clutter_actor_raise_top(to_main_menu);
+  clutter_actor_show (to_main_menu);
 
   chum_play_sequencer();
-ClutterActor *s1 = config_get_configured_actor(NULL,"house");
-clutter_container_add_actor (CLUTTER_CONTAINER (stage), s1);
-clutter_actor_set_position (s1, 720, 5); 
-clutter_actor_set_size (s1, 66, 60);
-clutter_actor_show (s1);
-clutter_actor_set_name(s1, "house");
-clutter_actor_set_reactive(s1, TRUE);
-g_signal_connect (s1, "button-release-event", G_CALLBACK (back_to_game_selection),NULL);
-    }
-
-
-
+}
