@@ -25,14 +25,10 @@ This is the singing game. Like karaoke.
 //This is list of actors we need.
 ClutterActor *contour_star;	/*When capturing and analysing pitch*/
 ClutterActor *display_freq;	/*Captured pitch in text (debug)*/
-ClutterActor *clef;		/*when recorder singing is playing*/
-ClutterActor *microphone;	/*when recording*/
 ClutterActor *group_of_songs;	/*All songs (these are clickable)*/
-ClutterActor *next;		/*For skipping stages*/
-ClutterActor *back;		/*For going back*/
+ClutterActor *cross;		/*For skipping stages*/
 ClutterActor *background;	/*This is bottom of all*/
 ClutterActor *big_image;	/*Currently played song*/
-ClutterActor *mentor; /*For mentor*/
 ClutterActor *language_chooser; /*Changing language for next song*/
 ClutterActor *choose_finnish;
 ClutterActor *choose_german;
@@ -40,10 +36,12 @@ ClutterActor *choose_english;
 ClutterActor *duetto_solo;    /*for choosing is teacher's sing muted or not*/
 ClutterActor *choose_duetto;
 ClutterActor *choose_solo;
-ClutterActor *singinggame_back_to_mainmenu=NULL; /*Button back to main_menu.*/
+
 extern ClutterActor* star_trace;
 extern JammoRecordingTrack* recording_track;
 extern char* selected_language;
+extern ClutterActor* mentor;
+extern ClutterActor *to_main_menu;
 
 static void init_song_table();
 	
@@ -149,7 +147,6 @@ FIXME. this is very similar than load_song_image
 static ClutterActor* load_song_background_image(int i){
   //printf("%d\n",i);
   ClutterActor* actor = clutter_texture_new ();
-  //g_object_set(G_OBJECT(actor), "load-async", TRUE, NULL);
   gchar* filepath1;
 
   filepath1 = g_strdup_printf("%s/background%s.png", chum_get_song_folder(i),selected_language );
@@ -167,12 +164,12 @@ static ClutterActor* load_song_background_image(int i){
       }
     else
       {
-      //g_object_set(G_OBJECT(actor), "load-async", TRUE, NULL);
+      g_object_set(G_OBJECT(actor), "load-async", TRUE, NULL);
       clutter_texture_set_from_file (CLUTTER_TEXTURE (actor), filepath1, NULL);
       }
     }
   else
-    
+    g_object_set(G_OBJECT(actor), "load-async", TRUE, NULL);
     clutter_texture_set_from_file (CLUTTER_TEXTURE (actor), filepath1, NULL);
   return actor;
 }
@@ -225,12 +222,6 @@ static void picture_of_song_pressed(JammoTexture *actor, ClutterEvent *event, gp
   gui_go_screen(SCREEN_SONG_RECORDING);
 }
 
-
-static void from_song_selection_to_game_selection(){
-  //chum_stop_sequencer();
-  chum_go_screen(SCREEN_GAME_SELECTION);
-}
-
 static void language_chosen(JammoTexture *actor, ClutterEvent *event, gpointer data){
   int i = GPOINTER_TO_INT(data);
   //g_print("pressed language number: %d \n", i);
@@ -298,7 +289,7 @@ static void duetto_solo_callback(){
 
 }
 
-static void next_pressed(){
+static void cross_pressed(){
   chum_stop_sequencer();
   chum_go_next();
 }
@@ -319,7 +310,7 @@ static void init_song_table(){
 
   clutter_actor_set_position (group_of_songs,0,0);
   clutter_container_add_actor (CLUTTER_CONTAINER (main_getStage()), group_of_songs);
-  //clutter_actor_hide (group_of_songs);
+  clutter_actor_hide (group_of_songs);
 
 	
   GList *song_list=chum_get_all_songs();
@@ -371,7 +362,7 @@ void init_singing_game(){
   background =clutter_rectangle_new_with_color (get_green_color());
   clutter_actor_set_size (background, WIDTH_OF_WINDOW,HEIGHT_OF_WINDOW);
   clutter_actor_set_position (background, 0, 0); 
-  //clutter_actor_hide (background);
+  clutter_actor_hide (background);
   clutter_container_add_actor (CLUTTER_CONTAINER (stage), background);
 
   //Text label of currently captured pitch
@@ -387,13 +378,9 @@ void init_singing_game(){
   clutter_container_add_actor (CLUTTER_CONTAINER (stage), contour_star);
   clutter_actor_hide (contour_star);
 
-  mentor = config_get_configured_actor(NULL,"button-2"); //this is mentor/help button FIXME:name
-  clutter_container_add_actor (CLUTTER_CONTAINER (stage), mentor);
-  //clutter_actor_hide (mentor);
-
   language_chooser = config_get_configured_actor(NULL,"language"); 
   clutter_container_add_actor (CLUTTER_CONTAINER (stage), language_chooser);
-  //clutter_actor_hide (language_chooser);
+  clutter_actor_hide (language_chooser);
   clutter_actor_set_reactive(language_chooser, TRUE);
   g_signal_connect (language_chooser, "button-press-event", G_CALLBACK (language_callback),NULL);
 
@@ -409,7 +396,7 @@ void init_singing_game(){
 
   duetto_solo = config_get_configured_actor(NULL,"duetto_solo"); 
   clutter_container_add_actor (CLUTTER_CONTAINER (stage), duetto_solo);
-  //clutter_actor_hide (duetto_solo);
+  clutter_actor_hide (duetto_solo);
   clutter_actor_set_reactive(duetto_solo, TRUE);
   g_signal_connect (duetto_solo, "button-press-event", G_CALLBACK (duetto_solo_callback),NULL);
  
@@ -420,19 +407,14 @@ void init_singing_game(){
   clutter_container_add_actor (CLUTTER_CONTAINER (stage), choose_duetto);
   clutter_actor_hide (choose_duetto);
 	
-  //Image of clef. Showed when recorded singing is playing
-  
-  //Image of microphone. Showed when recorded singing is playing
-  
-  //Button for going next stage (this is button and defined in button.c). NOT AT THIS MOMENT!
-  next = config_get_configured_actor(NULL,"cross");
-  clutter_actor_set_reactive(next, TRUE);
-  clutter_container_add_actor (CLUTTER_CONTAINER (stage), next);
-  clutter_actor_hide(next);
-  g_signal_connect (next, "button-press-event", G_CALLBACK (next_pressed), GINT_TO_POINTER(1));
+  //If user want skip listening before whole song is recorded. Or song_selection before playback ends.
+  cross = config_get_configured_actor(NULL,"cross");
+  clutter_actor_set_reactive(cross, TRUE);
+  clutter_container_add_actor (CLUTTER_CONTAINER (stage), cross);
+  clutter_actor_hide(cross);
+  g_signal_connect (cross, "button-press-event", G_CALLBACK (cross_pressed), GINT_TO_POINTER(1));
+
 
-  //Button for going previous stage (this is button and defined in button.c) NOT AT THIS MOMENT!
-  
   //This handles all adding etc
   init_song_table(""); //TODO. check language from profile.
 
@@ -443,25 +425,20 @@ void init_singing_game(){
   clutter_actor_hide(star_trace);
 		
 		
-  //Back to main-menu button.
-  singinggame_back_to_mainmenu = config_get_configured_actor(NULL,"main");
-  clutter_container_add_actor (CLUTTER_CONTAINER (stage), singinggame_back_to_mainmenu);
-  //clutter_actor_hide (singinggame_back_to_mainmenu);
-  clutter_actor_set_name(singinggame_back_to_mainmenu, "singinggame_back_to_mainmenu");
-  clutter_actor_set_reactive(singinggame_back_to_mainmenu, TRUE);
-  g_signal_connect (singinggame_back_to_mainmenu, "button-press-event", G_CALLBACK (from_song_selection_to_game_selection),NULL);
+
 }
 
 
 void start_mobikid_play_recorded(){
 		clear_trace(); //clear trace and move star to begin
 		
-    //clutter_actor_hide (microphone);
     clutter_actor_hide (display_freq);
     clutter_actor_hide (contour_star);
 
-    //clutter_actor_show (clef);
-    //clutter_actor_raise_top(clef);
+    //for some reason, this cross will hide otherwise
+    clutter_actor_show (cross);
+    clutter_actor_raise_top (cross);
+    clutter_actor_set_reactive(cross, TRUE);
 
     chum_play_sequencer();
 }
@@ -471,7 +448,6 @@ void start_mobikid_recording(){
   ClutterActor* stage =main_getStage();
 
   clutter_actor_hide(group_of_songs);
-  //clutter_actor_hide(clef);
 
   //Image of currently playing song
   //FIXME 'big_image' = background
@@ -516,9 +492,9 @@ void start_mobikid_recording(){
 //  clutter_actor_show (microphone);
 //  clutter_actor_raise_top (microphone);
 
-  clutter_actor_show (next);
-  clutter_actor_raise_top (next);
-  clutter_actor_set_reactive(next, TRUE);
+  clutter_actor_show (cross);
+  clutter_actor_raise_top (cross);
+  clutter_actor_set_reactive(cross, TRUE);
 
   clutter_actor_hide (language_chooser);
 //  clutter_actor_raise_top (back);
@@ -534,8 +510,8 @@ void start_mobikid_recording(){
 	clutter_actor_show(star_trace);
 	clutter_actor_raise_top (star_trace);
 
-  clutter_actor_lower_bottom(singinggame_back_to_mainmenu);
-  clutter_actor_hide (singinggame_back_to_mainmenu);
+  clutter_actor_lower_bottom(to_main_menu);
+  clutter_actor_hide (to_main_menu);
 
   printf("will start sequencer\n");
   chum_play_sequencer();
@@ -543,7 +519,7 @@ void start_mobikid_recording(){
 
 gboolean singing_game_is_initialized(){
   //printf("singing_game_is_initialized called. will return %d\n",singinggame_back_to_mainmenu!=NULL);
-  return (singinggame_back_to_mainmenu!=NULL); //last actor
+  return (language_chooser!=NULL); //last actor
 }
 
 /*
@@ -579,14 +555,11 @@ void start_mobikid_selection(){
   //clutter_actor_raise_top (back);
   //clutter_actor_show (back);
 
-  clutter_actor_raise_top(singinggame_back_to_mainmenu);
-  clutter_actor_show (singinggame_back_to_mainmenu);
+  clutter_actor_raise_top(to_main_menu);
+  clutter_actor_show (to_main_menu);
 
   //If this isn't first round these can be visible. So hide them
   clutter_actor_hide (display_freq);
   clutter_actor_hide (contour_star);
-  //clutter_actor_hide (microphone);
-  //clutter_actor_hide (clef);
-  clutter_actor_hide (next);
-  //clutter_actor_hide (back);
+  clutter_actor_hide (cross);
 }
