@@ -28,15 +28,6 @@ struct _JammoInstrumentTrackPrivate {
 	struct timeval creation_time;
 };
 
-/**
- * 
-instruments:
-0=flute
-1=drumkit
-2=ud
-3=slider (slider have own instrument parameter too)
- */
-
 JammoInstrumentTrack* jammo_instrument_track_new(JammoInstrumentType instrument_type) {
 	return JAMMO_INSTRUMENT_TRACK(g_object_new(JAMMO_TYPE_INSTRUMENT_TRACK,"instrument-type",instrument_type,NULL));
 }
@@ -107,31 +98,25 @@ static GObject* jammo_instrument_track_constructor(GType type, guint n_propertie
 
 	int instrument_nro = instrument_track->priv->instrument_type;
 	printf ("Type of instrument is: %d\n",instrument_nro);
-				
-	if (instrument_nro==3)	{
-		//Slider is different element than sampler, it has own 'instrument' parameter.
-		instrument_track->priv->element = gst_element_factory_make("jammoslider", NULL);
-		g_object_set(G_OBJECT(instrument_track->priv->element), "instrument", 2, NULL); //2=karplus-stronger
-	} else {
-		instrument_track->priv->element = gst_element_factory_make("jammosampler", NULL);
+	
+	instrument_track->priv->element = gst_element_factory_make("jammosampler", NULL);
 
-		//We must first define folder of samples
-		g_object_set(G_OBJECT(instrument_track->priv->element), "instrument-folder", INSTRUMENT_FOLDER, NULL);
-		char *buffer=NULL;
-		buffer=g_strdup_printf("%s%s",INSTRUMENT_FOLDER,"flute.txt"); //Default value
-		
-		if (instrument_nro==0){
-				buffer=g_strdup_printf("%s%s",INSTRUMENT_FOLDER,"flute.txt");
-		}
-		if (instrument_nro==1){
-				buffer=g_strdup_printf("%s%s",INSTRUMENT_FOLDER,"drumkit.txt");
-		}
-		if (instrument_nro==2){
-				buffer=g_strdup_printf("%s%s",INSTRUMENT_FOLDER,"ud.txt");
-		}
+	//We must first define folder of samples
+	g_object_set(G_OBJECT(instrument_track->priv->element), "instrument-folder", INSTRUMENT_FOLDER, NULL);
+	char *buffer=NULL;
+	buffer=g_strdup_printf("%s%s",INSTRUMENT_FOLDER,"flute.txt"); //Default value
 
-		g_object_set(G_OBJECT(instrument_track->priv->element), "init-instrument", buffer, NULL);
+	if (instrument_nro==JAMMO_INSTRUMENT_TYPE_FLUTE){
+			buffer=g_strdup_printf("%s%s",INSTRUMENT_FOLDER,"flute.txt");
 	}
+	if (instrument_nro==JAMMO_INSTRUMENT_TYPE_DRUMKIT){
+			buffer=g_strdup_printf("%s%s",INSTRUMENT_FOLDER,"drumkit.txt");
+	}
+	if (instrument_nro==JAMMO_INSTRUMENT_TYPE_UD){
+			buffer=g_strdup_printf("%s%s",INSTRUMENT_FOLDER,"ud.txt");
+	}
+
+	g_object_set(G_OBJECT(instrument_track->priv->element), "init-instrument", buffer, NULL);
 
 	gettimeofday(&instrument_track->priv->creation_time, NULL);
 
@@ -205,15 +190,6 @@ void jammo_instrument_track_set_note(JammoInstrumentTrack* instrument_track,char
 	printf("INSTRUMENT_TRACK: %ld.%ld: note %c%d toggled\n", timestamp.tv_sec,timestamp.tv_usec,note,octave); 
 }
 
-void jammo_instrument_track_set_slider_frequency(JammoInstrumentTrack* instrument_track,int a){
-	gfloat a2=(gfloat)a+100;
-	g_object_set(G_OBJECT(instrument_track->priv->element), "slider-freq", a2, NULL);
-}
-
-void jammo_instrument_track_set_slider_state(JammoInstrumentTrack* instrument_track,gboolean b){
-	g_object_set(G_OBJECT(instrument_track->priv->element), "slider-state", b, NULL);
-}
-
 static void jammo_instrument_track_init(JammoInstrumentTrack* instrument_track) {
 	instrument_track->priv = G_TYPE_INSTANCE_GET_PRIVATE(instrument_track, JAMMO_TYPE_INSTRUMENT_TRACK, JammoInstrumentTrackPrivate);
 }
